from .square import square
from .pyramid import pyramid
from .pyramid import numeric_pyramid
from .right_triangle import right_triangle

__all__ = ["square", "right_triangle", "pyramid", "numeric_pyramid"]